use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.19

use Test::More 0.88;
use Test::EOL;

my @files = (
    'lib/Protocol/Database/PostgreSQL.pm',
    'lib/Protocol/Database/PostgreSQL/Backend.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/AuthenticationRequest.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/AuthenticationRequest.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/BackendKeyData.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/BackendKeyData.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/BindComplete.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/BindComplete.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/CloseComplete.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/CloseComplete.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/CommandComplete.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/CommandComplete.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/CopyBothResponse.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/CopyBothResponse.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/CopyData.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/CopyData.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/CopyDone.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/CopyDone.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/CopyInResponse.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/CopyInResponse.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/CopyOutResponse.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/CopyOutResponse.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/DataRow.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/DataRow.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/EmptyQueryResponse.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/EmptyQueryResponse.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/ErrorResponse.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/ErrorResponse.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/FunctionCallResponse.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/FunctionCallResponse.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/NoData.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/NoData.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/NoticeResponse.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/NoticeResponse.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/NotificationResponse.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/NotificationResponse.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/ParameterDescription.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/ParameterDescription.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/ParameterStatus.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/ParameterStatus.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/ParseComplete.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/ParseComplete.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/PortalSuspended.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/PortalSuspended.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/ReadyForQuery.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/ReadyForQuery.pod',
    'lib/Protocol/Database/PostgreSQL/Backend/RowDescription.pm',
    'lib/Protocol/Database/PostgreSQL/Backend/RowDescription.pod',
    'lib/Protocol/Database/PostgreSQL/Client.pm',
    'lib/Protocol/Database/PostgreSQL/Client.pod',
    'lib/Protocol/Database/PostgreSQL/Constants.pm',
    'lib/Protocol/Database/PostgreSQL/Error.pm',
    'lib/Protocol/Database/PostgreSQL/Error.pod',
    'lib/Protocol/Database/PostgreSQL/Message.pm',
    't/00-check-deps.t',
    't/00-compile.t',
    't/00-report-prereqs.dd',
    't/00-report-prereqs.t',
    't/protocol.t',
    'xt/author/distmeta.t',
    'xt/author/eol.t',
    'xt/author/minimum-version.t',
    'xt/author/mojibake.t',
    'xt/author/no-tabs.t',
    'xt/author/pod-syntax.t',
    'xt/author/portability.t',
    'xt/author/test-version.t',
    'xt/release/common_spelling.t',
    'xt/release/cpan-changes.t'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
