package Protocol::Database::PostgreSQL::Client;

use strict;
use warnings;

our $VERSION = '2.000'; # VERSION

use parent q{Protocol::Database::PostgreSQL};

=head1 NAME

Protocol::Database::PostgreSQL::Client - support for the PostgreSQL wire protocol

=head1 SYNOPSIS


=head1 DESCRIPTION

=cut

1;

__END__

=head1 SEE ALSO

L<DBD::Pg>, which uses the official library and has had far more testing.

=head1 AUTHOR

Tom Molesworth <TEAM@cpan.org>

=head1 LICENSE

Copyright Tom Molesworth 2010-2019. Licensed under the same terms as Perl itself.

